@@ -58,17 +58,17 @@ struct cal_cbdata {
 	MAPIMeetingOptions meeting_type;
 	uint32_t appt_id;
 	uint32_t appt_seq;
-	const struct Binary_r *globalid;
-	const struct Binary_r *cleanglobalid;
+	struct Binary_r *globalid;
+	struct Binary_r *cleanglobalid;
 
 	uint32_t msgflags;
 	OlResponseStatus resp;
-	const gchar *username;
-	const gchar *useridtype;
-	const gchar *userid;
-	const gchar *ownername;
-	const gchar *owneridtype;
-	const gchar *ownerid;
+	gchar *username;
+	gchar *useridtype;
+	gchar *userid;
+	gchar *ownername;
+	gchar *owneridtype;
+	gchar *ownerid;
 
 	/* custom callback to get timezone from a backend */
 	gpointer get_tz_data;
@@ -91,7 +91,7 @@ void
 exchange_mapi_cal_util_generate_globalobjectid (gboolean is_clean, const gchar *uid, struct Binary_r *sb);
 
 gchar *
-exchange_mapi_cal_util_camel_helper (ExchangeMapiConnection *conn, mapi_id_t fid, mapi_id_t mid, const gchar *msg_class,
+exchange_mapi_cal_util_camel_helper (ExchangeMapiConnection *conn, mapi_id_t fid, mapi_id_t mid, mapi_object_t *obj_message, const gchar *msg_class,
 				   GSList *streams, GSList *recipients, GSList *attachments);
 
 uint32_t
@@ -101,6 +101,8 @@ gboolean exchange_mapi_cal_utils_add_named_ids (ExchangeMapiConnection *conn, ma
 gboolean exchange_mapi_cal_utils_get_props_cb (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *mem_ctx, struct SPropTagArray *props, gpointer data);
 gboolean exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *mem_ctx, struct SPropValue **values, uint32_t *n_values, gpointer data);
 
+gboolean exchange_mapi_cal_utils_get_free_busy_data (ExchangeMapiConnection *conn, const GList *users, time_t start, time_t end, GList **freebusy, GError **mapi_error);
+
 G_END_DECLS
 
 #endif
