@@ -172,7 +172,7 @@ exchange_mapi_util_find_SPropVal_array_namedid (struct SPropValue *values, Excha
 	g_return_val_if_fail (values != NULL, NULL);
 	g_return_val_if_fail (conn != NULL, NULL);
 
-	proptag = exchange_mapi_connection_resolve_named_prop (conn, fid, namedid);
+	proptag = exchange_mapi_connection_resolve_named_prop (conn, fid, namedid, NULL);
 	if (proptag != MAPI_E_RESERVED)
 		res = exchange_mapi_util_find_SPropVal_array_propval (values, proptag);
 
@@ -231,7 +231,7 @@ exchange_mapi_util_find_row_namedid (struct SRow *aRow, ExchangeMapiConnection *
 	g_return_val_if_fail (aRow != NULL, NULL);
 	g_return_val_if_fail (conn != NULL, NULL);
 
-	proptag = exchange_mapi_connection_resolve_named_prop (conn, fid, namedid);
+	proptag = exchange_mapi_connection_resolve_named_prop (conn, fid, namedid, NULL);
 	if (proptag != MAPI_E_RESERVED)
 		res = exchange_mapi_util_find_row_propval (aRow, proptag);
 
@@ -290,7 +290,7 @@ exchange_mapi_util_find_array_namedid (struct mapi_SPropValue_array *properties,
 	g_return_val_if_fail (properties != NULL, NULL);
 	g_return_val_if_fail (conn != NULL, NULL);
 
-	proptag = exchange_mapi_connection_resolve_named_prop (conn, fid, namedid);
+	proptag = exchange_mapi_connection_resolve_named_prop (conn, fid, namedid, NULL);
 	if (proptag != MAPI_E_RESERVED)
 		res = exchange_mapi_util_find_array_propval (properties, proptag);
 
@@ -930,7 +930,7 @@ exchange_crlf_to_lf (const gchar *in)
  *
  * Constructs profile name from given parameters and
  * returns it as a newly allocated string. It can also
- * rename old profile name string to a new name, if requested. 
+ * rename old profile name string to a new name, if requested.
  **/
 gchar *
 exchange_mapi_util_profile_name (const gchar *username, const gchar *domain, const gchar *hostname, gboolean migrate)
@@ -988,7 +988,7 @@ exchange_mapi_utils_add_named_ids_to_props_array (ExchangeMapiConnection *conn,
 	g_return_val_if_fail (named_ids_list != NULL, FALSE);
 	g_return_val_if_fail (named_ids_n_elems > 0, FALSE);
 
-	if (!exchange_mapi_connection_resolve_named_props (conn, fid, named_ids_list, named_ids_n_elems))
+	if (!exchange_mapi_connection_resolve_named_props (conn, fid, named_ids_list, named_ids_n_elems, NULL))
 		return FALSE;
 
 	for (i = 0; i < named_ids_n_elems; i++) {
@@ -1038,7 +1038,7 @@ exchange_mapi_utils_add_spropvalue_named_id (ExchangeMapiConnection *conn, mapi_
 	g_return_val_if_fail (values_array != NULL, FALSE);
 	g_return_val_if_fail (n_values != NULL, FALSE);
 
-	prop_tag = exchange_mapi_connection_resolve_named_prop (conn, fid, named_id);
+	prop_tag = exchange_mapi_connection_resolve_named_prop (conn, fid, named_id, NULL);
 	if (prop_tag == MAPI_E_RESERVED)
 		return FALSE;
 
@@ -1108,3 +1108,31 @@ exchange_mapi_utils_push_crc32 (uint32_t crc32, uint8_t *bytes, uint32_t n_bytes
 
 	return crc32;
 }
+
+/* copies a Binary_r, which should be freed with exchange_mapi_util_free_binary_r() */
+struct Binary_r *
+exchange_mapi_util_copy_binary_r (const struct Binary_r *bin)
+{
+	struct Binary_r *res;
+
+	if (!bin || !bin->cb)
+		return NULL;
+
+	res = g_new0 (struct Binary_r, 1);
+	res->cb = bin->cb;
+	res->lpb = g_new (uint8_t, res->cb);
+	memcpy (res->lpb, bin->lpb, res->cb);
+
+	return res;
+}
+
+/* frees Binary_r previously allocated by exchange_mapi_util_copy_binary_r() */
+void
+exchange_mapi_util_free_binary_r (struct Binary_r *bin)
+{
+	if (!bin)
+		return;
+
+	g_free (bin->lpb);
+	g_free (bin);
+}
